@@ -5,7 +5,8 @@
    Copyright (C) 2002 Carsten Pfeiffer <pfeiffer@kde.org>
    Copyright (C) 2006 - 2008 Urs Wolfer <uwolfer @ kde.org>
    Copyright (C) 2006 Dario Massarin <nekkar@libero.it>
-   Copyright (C) 2008 - 2009 Lukas Appelhans <l.appelhans@gmx.de>
+   Copyright (C) 2008 - 2011 Lukas Appelhans <l.appelhans@gmx.de>
+   Copyright (C) 2009 - 2010 Matthias Fuchs <mat69@gmx.net>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -21,6 +22,7 @@
 #include "core/transfertreemodel.h"
 #include "core/transfertreeselectionmodel.h"
 #include "settings.h"
+#include "conf/autopastemodel.h"
 #include "conf/preferencesdialog.h"
 #include "ui/viewscontainer.h"
 #include "ui/tray.h"
@@ -32,7 +34,7 @@
 #include "ui/linkview/kget_linkview.h"
 #include "ui/metalinkcreator/metalinkcreator.h"
 #include "extensions/webinterface/httpserver.h"
-#ifdef DEBUG
+#ifdef DO_KGET_TEST
     #include "tests/testkget.h"
 #endif
 
@@ -51,6 +53,7 @@
 #include <klocale.h>
 #include <kicon.h>
 #include <kactionmenu.h>
+#include <KSelectAction>
 #include <krun.h>
 #include <kicondialog.h>
 #include "core/verifier.h"
@@ -74,13 +77,13 @@ MainWindow::MainWindow(bool showMainwindow, bool startWithoutAnimation, bool doT
     // create the model
     m_kget = KGet::self( this );
 
+    m_viewsContainer = new ViewsContainer(this);
+
     // create actions
     setupActions();
 
     createGUI("kgetui.rc");
 
-    m_viewsContainer = new ViewsContainer(this);
-
     setCentralWidget(m_viewsContainer);
 
     // restore position, size and visibility
@@ -98,8 +101,6 @@ MainWindow::~MainWindow()
 {
     //Save the user's transfers
     KGet::save();
-    
-    NewTransferDialog::del();
 
     slotSaveMyself();
     // reset konqueror integration (necessary if user enabled / disabled temporarily integration from tray)
@@ -113,7 +114,7 @@ MainWindow::~MainWindow()
 
 QSize MainWindow::sizeHint() const
 {
-    return QSize(720, 380);
+    return QSize(738, 380);
 }
 
 int MainWindow::transfersPercent()
@@ -135,57 +136,68 @@ int MainWindow::transfersPercent()
     }
 }
 
-void MainWindow::exportTransfers(bool plain)
-{
-    QString filter = "";
-    if (!plain) {
-        filter = "*.kgt|" + i18n("KGet Transfer List") + " (*.kgt)";
-    }
-
-    QString filename = KFileDialog::getSaveFileName
-        (KUrl(),
-         filter,
-         this,
-         i18n("Export Transfers")
-        );
-
-    if(!filename.isEmpty())
-        KGet::save(filename, plain);
-}
-
 void MainWindow::setupActions()
 {
     KAction *newDownloadAction = actionCollection()->addAction("new_download");
     newDownloadAction->setText(i18n("&New Download..."));
     newDownloadAction->setIcon(KIcon("document-new"));
     newDownloadAction->setShortcuts(KShortcut("Ctrl+N"));
+    newDownloadAction->setHelpText(i18n("Opens a dialog to add a transfer to the list"));
     connect(newDownloadAction, SIGNAL(triggered()), SLOT(slotNewTransfer()));
 
     KAction *openAction = actionCollection()->addAction("import_transfers");
     openAction->setText(i18n("&Import Transfers..."));
     openAction->setIcon(KIcon("document-open"));
     openAction->setShortcuts(KShortcut("Ctrl+I"));
+    openAction->setHelpText(i18n("Imports a list of transfers"));
     connect(openAction, SIGNAL(triggered()), SLOT(slotImportTransfers()));
 
     KAction *exportAction = actionCollection()->addAction("export_transfers");
     exportAction->setText(i18n("&Export Transfers List..."));
     exportAction->setIcon(KIcon("document-export"));
     exportAction->setShortcuts(KShortcut("Ctrl+E"));
+    exportAction->setHelpText(i18n("Exports the current transfers into a file"));
     connect(exportAction, SIGNAL(triggered()), SLOT(slotExportTransfers()));
 
-    KAction *exportPlainAction = actionCollection()->addAction("export_plain_transfers");
-    exportPlainAction->setText(i18n("&Export Transfers as Plain Text..."));
-    exportPlainAction->setIcon(KIcon("document-export"));
-    exportPlainAction->setShortcuts(KShortcut("Ctrl+P"));
-    connect(exportPlainAction, SIGNAL(triggered()), SLOT(slotExportPlainTransfers()));
-
     KAction *createMetalinkAction = actionCollection()->addAction("create_metalink");
-    createMetalinkAction->setText(i18n("&Create a Metalink"));
+    createMetalinkAction->setText(i18n("&Create a Metalink..."));
+    createMetalinkAction->setIcon(KIcon("journal-new"));
+    createMetalinkAction->setHelpText(i18n("Creates or modifies a metalink and saves it on disk"));
     connect(createMetalinkAction, SIGNAL(triggered()), SLOT(slotCreateMetalink()));
 
+    KAction *priorityTop = actionCollection()->addAction("priority_top");
+    priorityTop->setText(i18n("Top Priority"));
+    priorityTop->setIcon(KIcon("arrow-up-double"));
+    priorityTop->setShortcuts(KShortcut("Ctrl+PgUp"));
+    priorityTop->setHelpText(i18n("Download selected transfer first"));
+    connect(priorityTop, SIGNAL(triggered()), this, SLOT(slotPriorityTop()));
+
+    KAction *priorityBottom = actionCollection()->addAction("priority_bottom");
+    priorityBottom->setText(i18n("Least Priority"));
+    priorityBottom->setIcon(KIcon("arrow-down-double"));
+    priorityBottom->setShortcuts(KShortcut("Ctrl+PgDown"));
+    priorityBottom->setHelpText(i18n("Download selected transfer last"));
+    connect(priorityBottom, SIGNAL(triggered()), this, SLOT(slotPriorityBottom()));
+
+    KAction *priorityUp = actionCollection()->addAction("priority_up");
+    priorityUp->setText(i18n("Increase Priority"));
+    priorityUp->setIcon(KIcon("arrow-up"));
+    priorityUp->setShortcuts(KShortcut("Ctrl+Up"));
+    priorityUp->setHelpText(i18n("Increase priority for selected transfer"));
+    connect(priorityUp, SIGNAL(triggered()), this, SLOT(slotPriorityUp()));
+
+    KAction *priorityDown = actionCollection()->addAction("priority_down");
+    priorityDown->setText(i18n("Decrease Priority"));
+    priorityDown->setIcon(KIcon("arrow-down"));
+    priorityDown->setShortcuts(KShortcut("Ctrl+Down"));
+    priorityDown->setHelpText(i18n("Decrease priority for selected transfer"));
+    connect(priorityDown, SIGNAL(triggered()), this, SLOT(slotPriorityDown()));
+
+    //FIXME: Not needed maybe because the normal delete already deletes groups?
     KAction *deleteGroupAction = actionCollection()->addAction("delete_groups");
     deleteGroupAction->setText(i18n("Delete Group"));
     deleteGroupAction->setIcon(KIcon("edit-delete"));
+    deleteGroupAction->setHelpText(i18n("Delete selected group"));
     connect(deleteGroupAction, SIGNAL(triggered()), SLOT(slotDeleteGroup()));
 
     KAction *renameGroupAction = actionCollection()->addAction("rename_groups");
@@ -196,6 +208,7 @@ void MainWindow::setupActions()
     KAction *setIconGroupAction = actionCollection()->addAction("seticon_groups");
     setIconGroupAction->setText(i18n("Set Icon..."));
     setIconGroupAction->setIcon(KIcon("preferences-desktop-icons"));
+    setIconGroupAction->setHelpText(i18n("Select a custom icon for the selected group"));
     connect(setIconGroupAction, SIGNAL(triggered()), SLOT(slotSetIconGroup()));
 
     m_autoPasteAction = new KToggleAction(KIcon("edit-paste"),
@@ -225,16 +238,26 @@ void MainWindow::setupActions()
     m_menubarAction->setChecked(!menuBar()->isHidden());
 
     // Transfer related actions
+    actionCollection()->addAction(KStandardAction::SelectAll, "select_all", m_viewsContainer, SLOT(selectAll()));
+
     KAction *deleteSelectedAction = actionCollection()->addAction("delete_selected_download");
     deleteSelectedAction->setText(i18nc("delete selected transfer item", "Remove Selected"));
     deleteSelectedAction->setIcon(KIcon("edit-delete"));
     deleteSelectedAction->setShortcuts(KShortcut("Del"));
+    deleteSelectedAction->setHelpText(i18n("Removes selected transfer and deletes files from disk if it's not finished"));
     connect(deleteSelectedAction, SIGNAL(triggered()), SLOT(slotDeleteSelected()));
 
     KAction *deleteAllFinishedAction = actionCollection()->addAction("delete_all_finished");
     deleteAllFinishedAction->setText(i18nc("delete all finished transfers", "Remove All Finished"));
     deleteAllFinishedAction->setIcon(KIcon("edit-clear-list"));
+    deleteAllFinishedAction->setHelpText(i18n("Removes all finished transfers and leaves all files on disk"));
     connect(deleteAllFinishedAction, SIGNAL(triggered()), SLOT(slotDeleteFinished()));
+    
+    KAction *deleteSelectedIncludingFilesAction = actionCollection()->addAction("delete_selected_download_including_files");
+    deleteSelectedIncludingFilesAction->setText(i18nc("delete selected transfer item and files", "Remove Selected and Delete Files"));
+    deleteSelectedIncludingFilesAction->setIcon(KIcon("edit-delete"));
+    deleteSelectedIncludingFilesAction->setHelpText(i18n("Removes selected transfer and deletes files from disk in any case"));
+    connect(deleteSelectedIncludingFilesAction, SIGNAL(triggered()), SLOT(slotDeleteSelectedIncludingFiles()));
 
     KAction *redownloadSelectedAction = actionCollection()->addAction("redownload_selected_download");
     redownloadSelectedAction->setText(i18nc("redownload selected transfer item", "Redownload Selected"));
@@ -242,50 +265,46 @@ void MainWindow::setupActions()
     connect(redownloadSelectedAction, SIGNAL(triggered()), SLOT(slotRedownloadSelected()));
 
     KAction *startAllAction = actionCollection()->addAction("start_all_download");
-    startAllAction->setText(i18n("Start / Resume All"));
+    startAllAction->setText(i18n("Start All"));
     startAllAction->setIcon(KIcon("media-seek-forward"));
     startAllAction->setShortcuts(KShortcut("Ctrl+R"));
+    startAllAction->setHelpText(i18n("Starts / resumes all transfers"));
     connect(startAllAction, SIGNAL(triggered()), SLOT(slotStartAllDownload()));
 
     KAction *startSelectedAction = actionCollection()->addAction("start_selected_download");
-    startSelectedAction->setText(i18n("Start / Resume Selected"));
+    startSelectedAction->setText(i18n("Start Selected"));
     startSelectedAction->setIcon(KIcon("media-playback-start"));
+    startSelectedAction->setHelpText(i18n("Starts / resumes selected transfer"));
     connect(startSelectedAction, SIGNAL(triggered()), SLOT(slotStartSelectedDownload()));
 
     KAction *stopAllAction = actionCollection()->addAction("stop_all_download");
-    stopAllAction->setText(i18n("Stop All"));
+    stopAllAction->setText(i18n("Pause All"));
     stopAllAction->setIcon(KIcon("media-playback-pause"));
     stopAllAction->setShortcuts(KShortcut("Ctrl+P"));
+    stopAllAction->setHelpText(i18n("Pauses all transfers"));
     connect(stopAllAction, SIGNAL(triggered()), SLOT(slotStopAllDownload()));
 
     KAction *stopSelectedAction = actionCollection()->addAction("stop_selected_download");
     stopSelectedAction->setText(i18n("Stop Selected"));
     stopSelectedAction->setIcon(KIcon("media-playback-pause"));
+    stopSelectedAction->setHelpText(i18n("Pauses selected transfer"));
     connect(stopSelectedAction, SIGNAL(triggered()), SLOT(slotStopSelectedDownload()));
 
-    KActionMenu *startActionMenu = new KActionMenu(KIcon("media-playback-start"), i18n("Start / Resume"),
+    KActionMenu *startActionMenu = new KActionMenu(KIcon("media-playback-start"), i18n("Start"),
                                                      actionCollection());
     actionCollection()->addAction("start_menu", startActionMenu);
     startActionMenu->setDelayed(true);
-    startActionMenu->addAction(startAllAction);
     startActionMenu->addAction(startSelectedAction);
+    startActionMenu->addAction(startAllAction);
     connect(startActionMenu, SIGNAL(triggered()), SLOT(slotStartDownload()));
 
-    KActionMenu *stopActionMenu = new KActionMenu(KIcon("media-playback-pause"), i18n("Stop"),
+    KActionMenu *stopActionMenu = new KActionMenu(KIcon("media-playback-pause"), i18n("Pause"),
                                                     actionCollection());
     actionCollection()->addAction("stop_menu", stopActionMenu);
     stopActionMenu->setDelayed(true);
-    stopActionMenu->addAction(stopAllAction);
     stopActionMenu->addAction(stopSelectedAction);
+    stopActionMenu->addAction(stopAllAction);
     connect(stopActionMenu, SIGNAL(triggered()), SLOT(slotStopDownload()));
-
-    KActionMenu *deleteActionMenu = new KActionMenu(KIcon("edit-delete"), i18n("Remove"),
-                                                    actionCollection());    
-    actionCollection()->addAction("delete_menu", deleteActionMenu);
-    deleteActionMenu->setDelayed(true);
-    deleteActionMenu->addAction(deleteSelectedAction);
-    deleteActionMenu->addAction(deleteAllFinishedAction);
-    connect(deleteActionMenu, SIGNAL(triggered()), SLOT(slotDeleteSelected()));
     
     KAction *openDestAction = actionCollection()->addAction("transfer_open_dest");
     openDestAction->setText(i18n("Open Destination"));
@@ -329,6 +348,58 @@ void MainWindow::setupActions()
     listLinksAction->setIcon(KIcon("view-list-text"));
     listLinksAction->setShortcuts(KShortcut("Ctrl+L"));
     connect(listLinksAction, SIGNAL(triggered()), SLOT(slotShowListLinks()));
+
+    //create the download finished actions which can be displayed in the toolbar
+    KSelectAction *downloadFinishedActions = new KSelectAction(i18n("After downloads finished action"), this);//TODO maybe with name??
+    actionCollection()->addAction("download_finished_actions", downloadFinishedActions);
+    downloadFinishedActions->setHelpText(i18n("Choose an action that is executed after all downloads have been finished."));
+
+    KAction *noAction = downloadFinishedActions->addAction(i18n("No Action"));
+    connect(noAction, SIGNAL(triggered()), SLOT(slotDownloadFinishedActions()));
+    downloadFinishedActions->addAction(noAction);
+
+    KAction *quitAction = downloadFinishedActions->addAction(i18n("Quit KGet"));
+    quitAction->setData(KGet::Quit);
+    connect(quitAction, SIGNAL(triggered()), SLOT(slotDownloadFinishedActions()));
+    downloadFinishedActions->addAction(quitAction);
+
+#ifdef HAVE_KWORKSPACE
+    KAction *shutdownAction = downloadFinishedActions->addAction(i18n("Turn Off Computer"));
+    shutdownAction->setData(KGet::Shutdown);
+    connect(shutdownAction, SIGNAL(triggered()), SLOT(slotDownloadFinishedActions()));
+    downloadFinishedActions->addAction(shutdownAction);
+
+    KAction *hibernateAction = downloadFinishedActions->addAction(i18n("Hibernate Computer"));
+    hibernateAction->setData(KGet::Hibernate);
+    connect(hibernateAction, SIGNAL(triggered()), SLOT(slotDownloadFinishedActions()));
+    downloadFinishedActions->addAction(hibernateAction);
+
+    KAction *suspendAction = downloadFinishedActions->addAction(i18n("Suspend Computer"));
+    suspendAction->setData(KGet::Suspend);
+    connect(suspendAction, SIGNAL(triggered()), SLOT(slotDownloadFinishedActions()));
+    downloadFinishedActions->addAction(suspendAction);
+#endif
+
+    if (Settings::afterFinishActionEnabled()) {
+        downloadFinishedActions->setCurrentItem(Settings::afterFinishAction() + 1);
+    } else {
+        downloadFinishedActions->setCurrentItem(0);
+    }
+}
+
+void MainWindow::slotDownloadFinishedActions()
+{
+    KAction *action = static_cast<KAction*>(QObject::sender());
+    bool ok;
+    const int type = action->data().toInt(&ok);
+    if (ok) {
+        Settings::self()->setAfterFinishAction(type);
+    }
+
+    //only after finish actions have a number assigned
+    Settings::self()->setAfterFinishActionEnabled(ok);
+    Settings::self()->writeConfig();
+    slotNewConfig();
 }
 
 void MainWindow::init()
@@ -400,12 +471,12 @@ void MainWindow::init()
 
     connect(KGet::model(), SIGNAL(transfersAddedEvent(QList<TransferHandler*>)), this, SLOT(slotUpdateTitlePercent()));
     connect(KGet::model(), SIGNAL(transfersRemovedEvent(QList<TransferHandler*>)), this, SLOT(slotUpdateTitlePercent()));
-    connect(KGet::model(), SIGNAL(transfersChangedEvent(QMap<TransferHandler *, Transfer::ChangesFlags>)), 
-                           SLOT(slotTransfersChanged(QMap<TransferHandler *, Transfer::ChangesFlags>)));
-    connect(KGet::model(), SIGNAL(groupsChangedEvent(QMap<TransferGroupHandler *, TransferGroup::ChangesFlags>)),
-                           SLOT(slotGroupsChanged(QMap<TransferGroupHandler *, TransferGroup::ChangesFlags>)));
+    connect(KGet::model(), SIGNAL(transfersChangedEvent(QMap<TransferHandler*,Transfer::ChangesFlags>)), 
+                           SLOT(slotTransfersChanged(QMap<TransferHandler*,Transfer::ChangesFlags>)));
+    connect(KGet::model(), SIGNAL(groupsChangedEvent(QMap<TransferGroupHandler*,TransferGroup::ChangesFlags>)),
+                           SLOT(slotGroupsChanged(QMap<TransferGroupHandler*,TransferGroup::ChangesFlags>)));
 
-#ifdef DEBUG
+#ifdef DO_KGET_TEST
     if (m_doTesting)
     {
         // Unit testing
@@ -422,7 +493,7 @@ void MainWindow::slotToggleDropTarget()
 
 void MainWindow::slotNewTransfer()
 {
-    NewTransferDialog::showNewTransferDialog(KUrl(), this);
+    NewTransferDialogHandler::showNewTransferDialog(KUrl());
 }
 
 void MainWindow::slotImportTransfers()
@@ -479,7 +550,7 @@ void MainWindow::slotTransfersChanged(QMap<TransferHandler*, Transfer::ChangesFl
 void MainWindow::slotGroupsChanged(QMap<TransferGroupHandler*, TransferGroup::ChangesFlags> groups)
 {
     bool update = false;
-    foreach (TransferGroup::ChangesFlags groupFlags, groups)
+    foreach (const TransferGroup::ChangesFlags &groupFlags, groups)
     {
         if (groupFlags & TransferGroup::Gc_Percent)
         {
@@ -509,16 +580,12 @@ void MainWindow::slotQuit()
 
 void MainWindow::slotPreferences()
 {
-    // an instance the dialog could be already created and could be cached,
-    // in which case you want to display the cached dialog
-    if ( PreferencesDialog::showDialog( "preferences" ) )
-        return;
-
-    // we didn't find an instance of this dialog, so lets create it
+    //never reuse the preference dialog, to make sure its settings are always reloaded
     PreferencesDialog * dialog = new PreferencesDialog( this, Settings::self() );
+    dialog->setAttribute(Qt::WA_DeleteOnClose);
 
     // keep us informed when the user changes settings
-    connect( dialog, SIGNAL(settingsChanged(const QString&)),
+    connect( dialog, SIGNAL(settingsChanged(QString)),
              this, SLOT(slotNewConfig()) );
 
     dialog->show();
@@ -526,12 +593,17 @@ void MainWindow::slotPreferences()
 
 void MainWindow::slotExportTransfers()
 {
-    exportTransfers(false);
-}
+    const QString filename = KFileDialog::getSaveFileName
+        (KUrl(),
+         "*.kgt|" + i18n("KGet Transfer List") + " (*.kgt)\n*.txt|" + i18n("Text File") + " (*.txt)",
+         this,
+         i18n("Export Transfers")
+        );
 
-void MainWindow::slotExportPlainTransfers()
-{
-    exportTransfers(true);
+    if (!filename.isEmpty()) {
+        const bool plain = !filename.endsWith("kgt");
+        KGet::save(filename, plain);
+    }
 }
 
 void MainWindow::slotCreateMetalink()
@@ -543,7 +615,11 @@ void MainWindow::slotCreateMetalink()
 
 void MainWindow::slotDeleteGroup()
 {
-    KGet::delGroups(KGet::selectedTransferGroups());
+    bool mainSelected;
+    QList<TransferGroupHandler*> groups = KGet::selectedTransferGroups(&mainSelected);
+    if (!mainSelected) {
+        KGet::delGroups(groups);
+    }
 }
 
 void MainWindow::slotRenameGroup()
@@ -580,10 +656,11 @@ void MainWindow::slotSetIconGroup()
 
 void MainWindow::slotStartDownload()
 {
-    if(KGet::selectedTransfers().size() == 0)
+    if (KGet::selectedTransfers().size() == 0 && KGet::selectedTransferGroups().size() == 0) {
         slotStartAllDownload();
-    else
+    } else {
         slotStartSelectedDownload();
+    }
 }
 
 void MainWindow::slotStartAllDownload()
@@ -597,15 +674,19 @@ void MainWindow::slotStartSelectedDownload()
     foreach (TransferHandler *transfer, KGet::selectedTransfers()) {
         transfer->start();
     }
+    foreach (TransferGroupHandler *group, KGet::selectedTransferGroups()) {
+        group->start();
+    }
     KGet::setSuspendScheduler(false);
 }
 
 void MainWindow::slotStopDownload()
 {
-    if(KGet::selectedTransfers().size() == 0)
+    if (KGet::selectedTransfers().size() == 0 && KGet::selectedTransferGroups().size() == 0) {
         slotStopAllDownload();
-    else
+    } else {
         slotStopSelectedDownload();
+    }
 }
 
 void MainWindow::slotStopAllDownload()
@@ -624,6 +705,9 @@ void MainWindow::slotStopSelectedDownload()
     foreach (TransferHandler *transfer, KGet::selectedTransfers()) {
         transfer->stop();
     }
+    foreach (TransferGroupHandler *group, KGet::selectedTransferGroups()) {
+        group->stop();
+    }
     KGet::setSuspendScheduler(false);
 }
 
@@ -631,7 +715,7 @@ void MainWindow::slotDeleteSelected()
 {
     foreach (TransferHandler * it, KGet::selectedTransfers())
     {
-        if (it->status() != Job::Finished) {
+        if (it->status() != Job::Finished && it->status() != Job::FinishedKeepAlive) {
             if (KMessageBox::warningYesNo(this,
                     i18np("Are you sure you want to delete the selected transfer?", 
                           "Are you sure you want to delete the selected transfers?", KGet::selectedTransfers().count()),
@@ -644,10 +728,38 @@ void MainWindow::slotDeleteSelected()
         }
     }
 
-    foreach (TransferHandler * it, KGet::selectedTransfers()) {
-        m_viewsContainer->closeTransferDetails(it);//TODO make it take QList?
+    const QList<TransferHandler*> selectedTransfers = KGet::selectedTransfers();
+    if (!selectedTransfers.isEmpty()) {
+        foreach (TransferHandler *it, selectedTransfers) {
+            m_viewsContainer->closeTransferDetails(it);//TODO make it take QList?
+        }
+        KGet::delTransfers(KGet::selectedTransfers());
+    } else {
+        //no transfers selected, delete groups if any are selected
+        slotDeleteGroup();
+    }
+}
+
+void MainWindow::slotDeleteSelectedIncludingFiles()
+{
+    const QList<TransferHandler*> selectedTransfers = KGet::selectedTransfers();
+
+    if (!selectedTransfers.isEmpty()) {
+        if (KMessageBox::warningYesNo(this,
+                i18np("Are you sure you want to delete the selected transfer including files?", 
+                        "Are you sure you want to delete the selected transfers including files?", selectedTransfers.count()),
+                i18n("Confirm transfer delete"),
+                KStandardGuiItem::remove(), KStandardGuiItem::cancel()) == KMessageBox::No) {
+            return;
+        }
+        foreach (TransferHandler *it, selectedTransfers) {
+            m_viewsContainer->closeTransferDetails(it);//TODO make it take QList?
+        }
+        KGet::delTransfers(KGet::selectedTransfers(), KGet::DeleteFiles);
+    } else {
+        //no transfers selected, delete groups if any are selected
+        slotDeleteGroup();
     }
-    KGet::delTransfers(KGet::selectedTransfers());
 }
 
 void MainWindow::slotRedownloadSelected()
@@ -658,6 +770,141 @@ void MainWindow::slotRedownloadSelected()
     }
 }
 
+void MainWindow::slotPriorityTop()
+{
+    QList<TransferHandler*> selected = KGet::selectedTransfers();
+    TransferHandler *after = 0;
+    TransferGroupHandler *group = 0;
+    foreach (TransferHandler *transfer, selected) {
+        if (!transfer) {
+            continue;
+        }
+
+        //previous transfer was not of the same group, so after has to be reset as the group
+        if (!group || (group != transfer->group())) {
+            after = 0;
+            group = transfer->group();
+        }
+        KGet::model()->moveTransfer(transfer, group, after);
+        after = transfer;
+    }
+}
+
+void MainWindow::slotPriorityBottom()
+{
+    QList<TransferHandler*> selected = KGet::selectedTransfers();
+    QList<TransferHandler*> groupTransfers;
+    TransferHandler *after = 0;
+    TransferGroupHandler *group = 0;
+    foreach (TransferHandler *transfer, selected) {
+        if (!transfer) {
+            continue;
+        }
+
+        //previous transfer was not of the same group, so after has to be reset as the group
+        if (!group || (group != transfer->group())) {
+            group = transfer->group();
+            groupTransfers = group->transfers();
+            if (groupTransfers.isEmpty()) {
+                after = 0;
+            } else {
+                after = groupTransfers.last();
+            }
+        }
+
+        KGet::model()->moveTransfer(transfer, group, after);
+        after = transfer;
+    }
+}
+
+void MainWindow::slotPriorityUp()
+{
+    QList<TransferHandler*> selected = KGet::selectedTransfers();
+    QList<TransferHandler*> groupTransfers;
+    TransferHandler *after = 0;
+    int newIndex = -1;
+    TransferGroupHandler *group = 0;
+    foreach (TransferHandler *transfer, selected) {
+        if (!transfer) {
+            continue;
+        }
+
+        //previous transfer was not of the same group, so group has to be reset
+        if (!group || (group != transfer->group())) {
+            group = transfer->group();
+            groupTransfers = group->transfers();
+        }
+
+        after = 0;
+        if (!groupTransfers.isEmpty()) {
+            int index = groupTransfers.indexOf(transfer);
+
+            //do not move higher than the first place
+            if (index > 0) {
+                //if only Transfers at the top are select do not change their order
+                if ((index - 1) != newIndex) {
+                    newIndex = index - 1;
+                    if (newIndex - 1 >= 0) {
+                        after = groupTransfers[newIndex - 1];
+                    }
+
+                    //keep the list with the actual movements synchronised
+                    groupTransfers.move(index, newIndex);
+
+                    KGet::model()->moveTransfer(transfer, group, after);
+                } else {
+                    newIndex = index;
+                }
+            } else {
+                newIndex = 0;
+            }
+        }
+    }
+}
+
+void MainWindow::slotPriorityDown()
+{
+    QList<TransferHandler*> selected = KGet::selectedTransfers();
+    QList<TransferHandler*> groupTransfers;
+    int newIndex = -1;
+    TransferGroupHandler *group = 0;
+    for (int i = selected.count() - 1; i >= 0; --i) {
+        TransferHandler *transfer = selected[i];
+        if (!transfer) {
+            continue;
+        }
+
+        //previous transfer was not of the same group, so group has to be reset
+        if (!group || (group != transfer->group())) {
+            group = transfer->group();
+            groupTransfers = group->transfers();
+        }
+
+        if (!groupTransfers.isEmpty()) {
+            int index = groupTransfers.indexOf(transfer);
+
+            //do not move lower than the last place
+            if ((index != -1) && (index + 1 < groupTransfers.count())) {
+                //if only Transfers at the top are select do not change their order
+                if ((index + 1) != newIndex) {
+                    newIndex = index + 1;
+                    TransferHandler *after = groupTransfers[newIndex];
+
+
+                    //keep the list with the actual movements synchronised
+                    groupTransfers.move(index, newIndex);
+
+                    KGet::model()->moveTransfer(transfer, group, after);
+                } else {
+                    newIndex = index;
+                }
+            } else {
+                newIndex = index;
+            }
+        }
+    }
+}
+
 void MainWindow::slotTransfersOpenDest()
 {
     QStringList openedDirs;
@@ -720,7 +967,7 @@ void MainWindow::slotConfigureKeys()
 void MainWindow::slotConfigureToolbars()
 {
     KEditToolBar edit( actionCollection() );
-    connect(&edit, SIGNAL( newToolbarConfig() ), this, SLOT( slotNewToolbarConfig() ));
+    connect(&edit, SIGNAL(newToolBarConfig()), this, SLOT(slotNewToolbarConfig()));
     edit.exec();
 }
 
@@ -771,6 +1018,8 @@ void MainWindow::slotNewConfig()
     } else if (m_webinterface && !Settings::webinterfaceEnabled()) {
         delete m_webinterface;
         m_webinterface = 0;
+    } else if (m_webinterface) {
+        m_webinterface->settingsChanged();
     }
 
     if (Settings::speedLimit())
@@ -810,7 +1059,26 @@ void MainWindow::slotCheckClipboard()
 
         const KUrl url = KUrl(lastClipboard);
         if (url.isValid() && !url.protocol().isEmpty() && url.hasPath() && url.hasHost() && !url.isLocalFile()) {
-            KGet::addTransfer( url );
+            bool add = false;
+            const QString urlString = url.url();
+
+            //check the combined whitelist and blacklist
+            const QList<int> types = Settings::autoPasteTypes();
+            const QList<int> syntaxes = Settings::autoPastePatternSyntaxes();
+            const QStringList patterns = Settings::autoPastePatterns();
+            const Qt::CaseSensitivity cs = (Settings::autoPasteCaseSensitive() ? Qt::CaseSensitive : Qt::CaseInsensitive);
+            for (int i = 0; i < types.count(); ++i) {
+                const QRegExp::PatternSyntax syntax = (syntaxes[i] == AutoPasteModel::Wildcard ? QRegExp::Wildcard : QRegExp::RegExp2);
+                QRegExp rx(patterns[i], cs, syntax);
+                if (rx.exactMatch(urlString)) {
+                    add = (types[i] == AutoPasteModel::Include);
+                    break;
+                }
+            }
+
+            if (add) {
+                KGet::addTransfer(url);
+            }
         }
     }
 }
@@ -818,7 +1086,7 @@ void MainWindow::slotCheckClipboard()
 void MainWindow::slotTrayKonquerorIntegration(bool enable)
 {
     slotKonquerorIntegration(enable);
-    if (!enable && Settings::konquerorIntegration() && !Settings::expertMode())
+    if (!enable && Settings::konquerorIntegration())
     {
         KGet::showNotification(this, "notification",
                                      i18n("KGet has been temporarily disabled as download manager for Konqueror. "
@@ -936,7 +1204,6 @@ void MainWindow::dragEnterEvent(QDragEnterEvent * event)
 void MainWindow::dropEvent(QDropEvent * event)
 {
     KUrl::List list = KUrl::List::fromMimeData(event->mimeData());
-    QString str;
 
     if (!list.isEmpty())
     {
@@ -947,24 +1214,21 @@ void MainWindow::dropEvent(QDropEvent * event)
                                        KGuiItem(i18n("&Load transfer list"), KIcon("list-add")), KStandardGuiItem::cancel());
 
             if (msgBoxResult == 3) //Download
-                NewTransferDialog::showNewTransferDialog(list.first().url(), this);
+                NewTransferDialogHandler::showNewTransferDialog(list.first().url());
             if (msgBoxResult == 4) //Load
                 KGet::load(list.first().url());
         }
         else
         {
             if (list.count() == 1)
-            {
-                str = event->mimeData()->text();
-                NewTransferDialog::showNewTransferDialog(str, this);
-            }
+                NewTransferDialogHandler::showNewTransferDialog(list.first().url());
             else
-                NewTransferDialog::showNewTransferDialog(list, this);
+                NewTransferDialogHandler::showNewTransferDialog(list);
         }
     }
     else
     {
-        NewTransferDialog::showNewTransferDialog(KUrl(), this);
+        NewTransferDialogHandler::showNewTransferDialog(KUrl());
     }
 }
 
