@@ -27,31 +27,28 @@ class KGetSortFilterProxyModel : public QSortFilterProxyModel
     Q_OBJECT
 
     public:
-        KGetSortFilterProxyModel(QObject *parent = 0);
+        explicit KGetSortFilterProxyModel(int sortColumn, QObject *parent = 0);
         virtual ~KGetSortFilterProxyModel();
 
         enum DownloadFilterType {
-            NoFilter = 0,
-            VideoFiles = 1,
-            AudioFiles = 2,
-            CompressedFiles = 3,
-            ImageFiles = 4
+            NoFilter,
+            VideoFiles,
+            AudioFiles,
+            CompressedFiles,
+            ImageFiles
         };
 
         enum FilterMode {
-            Contain = 0,
-            DoesNotContain = 1
+            Contain,
+            DoesNotContain
         };
 
-        DownloadFilterType filterType() const;
-        FilterMode filterMode() const;
+        void setFilterType(int filterType);
+        void setFilterMode(int filterMode);
+        void setFilterColumn(int column);
         bool showWebContent() const;
 
     public slots:
-        void setFilterType(DownloadFilterType filterType);
-        void setFilterType(int filterType);
-        void setFilterMode(FilterMode filterMode);
-        void setFilterMode(int filterMode);
         void setShowWebContent(bool show);
         void setShowWebContent(int show);
 
@@ -59,9 +56,23 @@ class KGetSortFilterProxyModel : public QSortFilterProxyModel
         virtual bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const;
 
     private:
-        DownloadFilterType m_filterType;
+        /**
+         * Returns true if text should be accepted by the filter
+         */
+        bool acceptText(const QString &text) const;
+
+        /**
+         * @param row to get the column from
+         * @return string for the column that is being filtered
+         */
+        QString columnText(int row, const QModelIndex &sourceParent) const;
+
+    private:
+        int m_filterType;
         FilterMode m_filterMode;
+        int m_column;
         bool m_showWebContent;
+        QHash<int, QString> m_mimeTypes;
 };
 
 #endif // KGET_SORTFILTERPROXYMODEL_H
