@@ -39,6 +39,7 @@
 #include <kicon.h>
 #include <kaction.h>
 #include <kmenu.h>
+#include <kcolordialog.h>
 
 #include "addaccountwizard.h"
 #include "editaccountwidget.h"
@@ -70,13 +71,16 @@ KopeteAccountConfig::KopeteAccountConfig( QWidget *parent, const QVariantList &a
 	configureMenus();
 
 	connect( mAccountList,  SIGNAL(itemPositionChanged()), this, SLOT(changed()) );
-	connect( mAccountList,  SIGNAL( itemSelectionChanged() ), this, SLOT( slotItemSelected() ) );
-	connect( mAccountList,  SIGNAL( itemDoubleClicked(QTreeWidgetItem*, int) ), this, SLOT( slotModify() ) );
-	connect( mAccountList,  SIGNAL( itemChanged ( QTreeWidgetItem * , int )), this, SLOT( slotItemChanged(QTreeWidgetItem*) ) );
-	connect( mAccountList,  SIGNAL( itemClicked ( QTreeWidgetItem * , int )), this, SLOT( slotItemClicked(QTreeWidgetItem*, int) ) );
+	connect( mAccountList,  SIGNAL(itemSelectionChanged()), this, SLOT(slotItemSelected()) );
+	connect( mAccountList,  SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)), this, SLOT(slotModify()) );
+	connect( mAccountList,  SIGNAL(itemChanged(QTreeWidgetItem*,int)), this, SLOT(slotItemChanged(QTreeWidgetItem*)) );
+	connect( mAccountList,  SIGNAL(itemClicked(QTreeWidgetItem*,int)), this, SLOT(slotItemClicked(QTreeWidgetItem*,int)) );
 
 	// this ensures that newly created accounts are assigned to the selected identity
-	connect( Kopete::AccountManager::self(), SIGNAL(accountRegistered(Kopete::Account *)), this, SLOT(slotAccountAdded(Kopete::Account *)) );
+	connect( Kopete::AccountManager::self(), SIGNAL(accountRegistered(Kopete::Account*)), this, SLOT(slotAccountAdded(Kopete::Account*)) );
+    connect( Kopete::AccountManager::self(), SIGNAL(accountUnregistered(const Kopete::Account*)), this, SLOT(slotAccountRemoved(const Kopete::Account*)) );
+
+	mAccountList->installEventFilter( this );
 
 	setButtons( Help );
 	load();
@@ -190,15 +194,15 @@ void KopeteAccountConfig::load()
 
 		lvi->setSizeHint( 0, QSize(0, 42) );
 		
-		lvi->setText( 1, account->myself()->onlineStatus().statusTypeToString(account->myself()->onlineStatus().status()) );
+		lvi->setText( 1, account->myself()->onlineStatus().description() );
 		lvi->setTextAlignment( 1, Qt::AlignRight | Qt::AlignVCenter );
 		lvi->setFont( 1, font );
 	
 		lvi->setFlags( (lvi->flags() & ~Qt::ItemIsDropEnabled) | Qt::ItemIsUserCheckable );
 		lvi->setCheckState ( 0, account->excludeConnect() ? Qt::Unchecked : Qt::Checked );
 
-		connect( account->myself(), SIGNAL(onlineStatusChanged(Kopete::Contact*, const Kopete::OnlineStatus&, const Kopete::OnlineStatus&)),
-				 this, SLOT(slotOnlineStatusChanged(Kopete::Contact*, const Kopete::OnlineStatus&, const Kopete::OnlineStatus&)));
+		connect( account->myself(), SIGNAL(onlineStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)),
+				 this, SLOT(slotOnlineStatusChanged(Kopete::Contact*,Kopete::OnlineStatus,Kopete::OnlineStatus)));
 	}
 
 	changed( false );
@@ -213,6 +217,7 @@ void KopeteAccountConfig::slotItemSelected()
 	mButtonAccountRemove->setEnabled( accountSelected );
 	m_actionAccountSwitchIdentity->setEnabled( accountSelected && hasMultipleIdentities );
 	mButtonAccountSwitchIdentity->setEnabled( m_actionAccountSwitchIdentity->isEnabled() );
+	mButtonAccountSetColor->setEnabled( accountSelected );
 
 	bool identitySelected = selectedIdentity();
 	bool isDefaultIdentity = (identitySelected && Kopete::IdentityManager::self()->defaultIdentity() == selectedIdentity()->identity());
@@ -311,7 +316,6 @@ void KopeteAccountConfig::removeAccount()
 					QString(), KMessageBox::Notify | KMessageBox::Dangerous ) == KMessageBox::Continue )
 		{
 			Kopete::AccountManager::self()->removeAccount( i );
-			delete lvi;
 		}
 	}
 }
@@ -375,6 +379,24 @@ void KopeteAccountConfig::slotAccountSwitchIdentity()
 	load();
 }
 
+void KopeteAccountConfig::slotAccountSetColor()
+{
+	KopeteAccountLVI *lvi = selectedAccount();
+
+	if ( !lvi || !lvi->account() )
+		return;
+
+	Kopete::Account *a = lvi->account();
+
+	QColor color = a->color();
+
+	if ( KColorDialog::getColor(color, Qt::black, this) == KColorDialog::Accepted ) {
+		a->setColor(color);
+	}
+
+	load();
+}
+
 void KopeteAccountConfig::slotSetDefaultIdentity()
 {
 	KopeteIdentityLVI *lvi = selectedIdentity();
@@ -449,7 +471,7 @@ void KopeteAccountConfig::slotOnlineStatusChanged( Kopete::Contact *contact,
 		if (i->account()->myself() == contact)
 		{
 			(*it)->setIcon( 0, newStatus.iconFor(i->account()) );
-			(*it)->setText( 1, contact->onlineStatus().statusTypeToString(newStatus.status()) );
+			(*it)->setText( 1, newStatus.description() );
 			break;
 		}
 	}
@@ -462,6 +484,21 @@ void KopeteAccountConfig::slotAccountAdded( Kopete::Account * account )
 	load();
 }
 
+void KopeteAccountConfig::slotAccountRemoved( const Kopete::Account * account )
+{
+	QList<QTreeWidgetItem*> items = mAccountList->findItems("", Qt::MatchContains | Qt::MatchRecursive);
+	QList<QTreeWidgetItem*>::iterator it;
+	for (it = items.begin(); it != items.end(); ++it)
+	{
+		KopeteAccountLVI *lvi = dynamic_cast<KopeteAccountLVI*>(*it);
+		if ( lvi && lvi->account() == account)
+		{
+			delete lvi;
+			break;
+		}
+	}
+}
+
 void KopeteAccountConfig::slotItemChanged(QTreeWidgetItem* item)
 {
 	if(!item)
@@ -478,19 +515,26 @@ void KopeteAccountConfig::slotItemChanged(QTreeWidgetItem* item)
 	}
 }
 
-void KopeteAccountConfig::contextMenuEvent ( QContextMenuEvent * event )
-{	
-	KopeteIdentityLVI *ilvi = selectedIdentity();
-	if ( ilvi && ilvi->identity() )
+bool KopeteAccountConfig::eventFilter( QObject *obj, QEvent *event )
+{
+	if ( obj == mAccountList && event->type() == QEvent::ContextMenu )
 	{
-		m_identityContextMenu->popup(event->globalPos());
+		QContextMenuEvent *cmEvent = static_cast<QContextMenuEvent *>(event);
+		KopeteIdentityLVI *ilvi = selectedIdentity();
+		if ( ilvi && ilvi->identity() )
+		{
+			m_identityContextMenu->popup(cmEvent->globalPos());
+		}
+
+		KopeteAccountLVI *alvi = selectedAccount();
+		if ( alvi && alvi->account() )
+		{
+			m_accountContextMenu->popup(cmEvent->globalPos());
+		}
+		return true;
 	}
 
-	KopeteAccountLVI *alvi = selectedAccount();
-	if ( alvi && alvi->account() )
-	{
-		m_accountContextMenu->popup(event->globalPos());
-	}
+	return QObject::eventFilter( obj, event );
 }
 
 void KopeteAccountConfig::configureActions()
@@ -526,6 +570,12 @@ void KopeteAccountConfig::configureActions()
 	connect( m_actionAccountSwitchIdentity, SIGNAL(triggered(bool)), this, SLOT(slotAccountSwitchIdentity()) );
 	connect( mButtonAccountSwitchIdentity, SIGNAL(clicked()), m_actionAccountSwitchIdentity, SLOT(trigger()) );
 
+	// Set/clear custom color for account
+	m_actionAccountSetColor = new KAction( i18n( "Set C&olor..." ), this );
+	mButtonAccountSetColor->setText( m_actionAccountSetColor->text() );
+	connect( m_actionAccountSetColor, SIGNAL(triggered(bool)), this, SLOT(slotAccountSetColor()) );
+	connect( mButtonAccountSetColor, SIGNAL(clicked()), m_actionAccountSetColor, SLOT(trigger()) );
+
 	// Add identity
 	m_actionIdentityAdd = new KAction( i18n( "Add &Identity..." ), this );
 	m_actionIdentityAdd->setIcon( KIcon("list-add") );
@@ -571,6 +621,7 @@ void KopeteAccountConfig::configureMenus()
 	m_accountContextMenu = new KMenu ( this );
 	m_accountContextMenu->addAction( m_actionAccountModify );
 	m_accountContextMenu->addAction( m_actionAccountRemove );
+	m_accountContextMenu->addAction( m_actionAccountSetColor );
 
 	// Identity management context menu
 	m_identityContextMenu = new KMenu ( this );
