@@ -64,6 +64,7 @@ GoogleTalk::GoogleTalk(const QString &jid, const QString &password) {
 	connect( callDialog->acceptButton, SIGNAL(pressed()), this, SLOT(acceptCall()) );
 	connect( callDialog->hangupButton, SIGNAL(pressed()), this, SLOT(hangupCall()) );
 	connect( callDialog->rejectButton, SIGNAL(pressed()), this, SLOT(rejectCall()) );
+	connect( callDialog, SIGNAL(closed()), this, SLOT(cancelCall()) );
 
 }
 
@@ -434,6 +435,14 @@ void GoogleTalk::hangupCall() {
 
 }
 
+void GoogleTalk::cancelCall() {
+
+//	qDebug() << "GoogleTalk::cancelCall";
+	hangupCall();
+	rejectCall();
+
+}
+
 void GoogleTalk::muteCall(bool b) {
 
 //	qDebug() << "GoogleTalk::muteCall";
