@@ -95,6 +95,8 @@ namespace
 	DefaultCodecProvider defaultCodecProvider;
 }
 
+namespace Oscar {
+
 class Client::ClientPrivate
 {
 public:
@@ -201,10 +203,10 @@ Client::Client( QObject* parent )
 	d->awayMsgRequestTimer = new QTimer();
 	d->codecProvider = &defaultCodecProvider;
 
-	connect( this, SIGNAL( redirectionFinished( Oscar::WORD ) ),
-	         this, SLOT( checkRedirectionQueue( Oscar::WORD ) ) );
-	connect( d->awayMsgRequestTimer, SIGNAL( timeout() ),
-	         this, SLOT( nextICQAwayMessageRequest() ) );
+	connect( this, SIGNAL(redirectionFinished(Oscar::WORD)),
+	         this, SLOT(checkRedirectionQueue(Oscar::WORD)) );
+	connect( d->awayMsgRequestTimer, SIGNAL(timeout()),
+	         this, SLOT(nextICQAwayMessageRequest()) );
 }
 
 Client::~Client()
@@ -224,17 +226,15 @@ Oscar::Settings* Client::clientSettings() const
 	return d->settings;
 }
 
-void Client::connectToServer( Connection *c, const QString& host, quint16 port, bool auth )
+void Client::connectToServer( const QString& host, quint16 port )
 {
-	d->connections.append( c );
-	if ( auth == true )
-	{
-		d->loginTask = new StageOneLoginTask( c->rootTask() );
-		connect( d->loginTask, SIGNAL( finished() ), this, SLOT( lt_loginFinished() ) );
-	}
+	ClientStream* cs = createClientStream();
+	Connection* c = new Connection( cs, "AUTHORIZER" );
+	c->setClient( this );
 
-	connect( c, SIGNAL( socketError( int, const QString& ) ), this, SLOT( determineDisconnection( int, const QString& ) ) );
-	c->connectToServer( host, port );
+	d->loginTask = new StageOneLoginTask( c->rootTask() );
+	connect( d->loginTask, SIGNAL(finished()), this, SLOT(lt_loginFinished()) );
+	connectToServer( c, host, port );
 }
 
 void Client::start( const QString &host, const uint port, const QString &userId, const QString &pass )
@@ -332,9 +332,9 @@ void Client::setStatus( Oscar::DWORD status, const QString &message, int xtraz,
 			sdcit->setIcqMood( mood );
 
 		if ( d->isIcq && statusInfoChanged )
-			sdcit->setIcqMessage( title );
-
-		sdcit->go( Task::AutoDelete ); //autodelete
+			sdcit->setStatusMessage( title );
+		if ( !d->isIcq && (status & 0xFF) == 0x00 ) //not icq and status is online
+			sdcit->setStatusMessage( message );
 
 		QString msg;
 		// AIM: you're away exactly when your away message isn't empty.
@@ -359,6 +359,8 @@ void Client::setStatus( Oscar::DWORD status, const QString &message, int xtraz,
 			pt->setXtrazStatus( xtraz );
 
 		pt->go( Task::AutoDelete );
+		//Has to be sent after ProfileTask otherwise the EA, DND will be wrong
+		sdcit->go( Task::AutoDelete );
 
 		d->status.sent = true;
 	}
@@ -414,13 +416,13 @@ void Client::lt_loginFinished()
 		kDebug(OSCAR_RAW_DEBUG) << "stage two done. setting up services";
 		initializeStaticTasks();
 		ServiceSetupTask* ssTask = new ServiceSetupTask( d->connections.defaultConnection()->rootTask() );
-		connect( ssTask, SIGNAL( finished() ), this, SLOT( serviceSetupFinished() ) );
+		connect( ssTask, SIGNAL(finished()), this, SLOT(serviceSetupFinished()) );
 		ssTask->go( Task::AutoDelete ); //fire and forget
 	}
 	else if ( d->stage == ClientPrivate::StageOne )
 	{
 		kDebug(OSCAR_RAW_DEBUG) << "stage one login done";
-		disconnect( d->loginTask, SIGNAL( finished() ), this, SLOT( lt_loginFinished() ) );
+		disconnect( d->loginTask, SIGNAL(finished()), this, SLOT(lt_loginFinished()) );
 
 		if ( d->loginTask->statusCode() == 0 ) //we can start stage two
 		{
@@ -431,7 +433,7 @@ void Client::lt_loginFinished()
 			d->port = d->loginTask->bosPort().toUInt();
 			d->cookie = d->loginTask->loginCookie();
 			close();
-			QTimer::singleShot( 100, this, SLOT(startStageTwo() ) );
+			QTimer::singleShot( 100, this, SLOT(startStageTwo()) );
 			d->stage = ClientPrivate::StageTwo;
 		}
 		else
@@ -454,11 +456,11 @@ void Client::startStageTwo()
 	//create the new login task
 	d->loginTaskTwo = new StageTwoLoginTask( c->rootTask() );
 	d->loginTaskTwo->setCookie( d->cookie );
-	QObject::connect( d->loginTaskTwo, SIGNAL( finished() ), this, SLOT( lt_loginFinished() ) );
+	QObject::connect( d->loginTaskTwo, SIGNAL(finished()), this, SLOT(lt_loginFinished()) );
 
 	//connect
-	QObject::connect( c, SIGNAL( connected() ), this, SLOT( streamConnected() ) );
-	connectToServer( c, d->host, d->port, false ) ;
+	QObject::connect( c, SIGNAL(connected()), this, SLOT(streamConnected()) );
+	connectToServer( c, d->host, d->port ) ;
 
 }
 
@@ -623,6 +625,7 @@ void Client::receivedMessage( const Oscar::Message& msg )
 		Oscar::Message response ( msg );
 		if ( msg.hasProperty( Oscar::Message::StatusMessageRequest ) )
 		{
+			kDebug( OSCAR_RAW_DEBUG ) << "Away message request";
 			QTextCodec* codec = d->codecProvider->codecForContact( msg.sender() );
 			response.setText( Oscar::Message::UserDefined, statusMessage(), codec );
 			emit userReadsStatusMessage( msg.sender() );
@@ -654,8 +657,7 @@ void Client::receivedMessage( const Oscar::Message& msg )
 			{
 				Buffer buffer;
 
-				QTextCodec* codec = d->codecProvider->codecForContact( msg.sender() );
-				buffer.addLEDBlock( codec->fromUnicode( statusMessage() ) );
+				buffer.addLEDBlock( statusMessage().toUtf8() );
 				//TODO: Change this to text/x-aolrtf
 				buffer.addLEDBlock( "text/plain" );
 
@@ -711,8 +713,7 @@ void Client::receivedMessage( const Oscar::Message& msg )
 				// we got a response to a status message request.
 				Buffer buffer( msg.plugin()->data() );
 
-				QTextCodec* codec = d->codecProvider->codecForContact( msg.sender() );
-				QString awayMessage = codec->toUnicode( buffer.getLEDBlock() );
+				QString awayMessage = QString::fromUtf8( buffer.getLEDBlock() );
 				kDebug( OSCAR_RAW_DEBUG ) << "Received an away message: " << awayMessage;
 				emit receivedAwayMessage( msg.sender(), awayMessage );
 			}
@@ -809,45 +810,45 @@ void Client::initializeStaticTasks()
 	d->typingNotifyTask = new TypingNotifyTask( c->rootTask() );
 	d->ssiModifyTask = new SSIModifyTask( c->rootTask(), true );
 
-	connect( d->onlineNotifier, SIGNAL( userIsOnline( const QString&, const UserDetails& ) ),
-	         this, SIGNAL( receivedUserInfo( const QString&, const UserDetails& ) ) );
-	connect( d->onlineNotifier, SIGNAL( userIsOffline( const QString&, const UserDetails& ) ),
-	         this, SLOT( offlineUser( const QString&, const UserDetails & ) ) );
+	connect( d->onlineNotifier, SIGNAL(userIsOnline(QString,UserDetails)),
+	         this, SIGNAL(receivedUserInfo(QString,UserDetails)) );
+	connect( d->onlineNotifier, SIGNAL(userIsOffline(QString,UserDetails)),
+	         this, SLOT(offlineUser(QString,UserDetails)) );
 
-	connect( d->ownStatusTask, SIGNAL( gotInfo() ), this, SLOT( haveOwnUserInfo() ) );
-	connect( d->ownStatusTask, SIGNAL( buddyIconUploadRequested() ), this,
-	         SIGNAL( iconNeedsUploading() ) );
+	connect( d->ownStatusTask, SIGNAL(gotInfo()), this, SLOT(haveOwnUserInfo()) );
+	connect( d->ownStatusTask, SIGNAL(buddyIconUploadRequested()), this,
+	         SIGNAL(iconNeedsUploading()) );
 
-	connect( d->messageReceiverTask, SIGNAL( receivedMessage( const Oscar::Message& ) ),
-	         this, SLOT( receivedMessage( const Oscar::Message& ) ) );
-	connect( d->messageReceiverTask, SIGNAL( fileMessage( int, const QString, const QByteArray, Buffer ) ),
-	         this, SLOT( gotFileMessage( int, const QString, const QByteArray, Buffer ) ) );
-	connect( d->messageReceiverTask, SIGNAL( chatroomMessage( const Oscar::Message&, const QByteArray & ) ),
-	         this, SLOT( gotChatRoomMessage( const Oscar::Message&, const QByteArray & ) ) );
+	connect( d->messageReceiverTask, SIGNAL(receivedMessage(Oscar::Message)),
+	         this, SLOT(receivedMessage(Oscar::Message)) );
+	connect( d->messageReceiverTask, SIGNAL(fileMessage(int,QString,QByteArray,Buffer)),
+	         this, SLOT(gotFileMessage(int,QString,QByteArray,Buffer)) );
+	connect( d->messageReceiverTask, SIGNAL(chatroomMessage(Oscar::Message,QByteArray)),
+	         this, SLOT(gotChatRoomMessage(Oscar::Message,QByteArray)) );
 
-	connect( d->messageAckTask, SIGNAL(messageAck(const QString&, uint)),
-	         this, SIGNAL(messageAck(const QString&, uint)) );
-	connect( d->errorTask, SIGNAL(messageError(const QString&, uint)),
-	         this, SIGNAL(messageError(const QString&, uint)) );
+	connect( d->messageAckTask, SIGNAL(messageAck(QString,uint)),
+	         this, SIGNAL(messageAck(QString,uint)) );
+	connect( d->errorTask, SIGNAL(messageError(QString,uint)),
+	         this, SIGNAL(messageError(QString,uint)) );
 	
-	connect( d->ssiAuthTask, SIGNAL( authRequested( const QString&, const QString& ) ),
-	         this, SIGNAL( authRequestReceived( const QString&, const QString& ) ) );
-	connect( d->ssiAuthTask, SIGNAL( authReplied( const QString&, const QString&, bool ) ),
-	         this, SIGNAL( authReplyReceived( const QString&, const QString&, bool ) ) );
+	connect( d->ssiAuthTask, SIGNAL(authRequested(QString,QString)),
+	         this, SIGNAL(authRequestReceived(QString,QString)) );
+	connect( d->ssiAuthTask, SIGNAL(authReplied(QString,QString,bool)),
+	         this, SIGNAL(authReplyReceived(QString,QString,bool)) );
 
-	connect( d->icqInfoTask, SIGNAL( receivedInfoFor( const QString&, unsigned int ) ),
-	         this, SLOT( receivedIcqInfo( const QString&, unsigned int ) ) );
-	connect( d->icqTlvInfoTask, SIGNAL(receivedInfoFor(const QString&)),
-	         this, SIGNAL(receivedIcqTlvInfo(const QString&)) );
+	connect( d->icqInfoTask, SIGNAL(receivedInfoFor(QString,uint)),
+	         this, SLOT(receivedIcqInfo(QString,uint)) );
+	connect( d->icqTlvInfoTask, SIGNAL(receivedInfoFor(QString)),
+	         this, SIGNAL(receivedIcqTlvInfo(QString)) );
 
-	connect( d->userInfoTask, SIGNAL( receivedProfile( const QString&, const QString& ) ),
-	         this, SIGNAL( receivedProfile( const QString&, const QString& ) ) );
-	connect( d->userInfoTask, SIGNAL( receivedAwayMessage( const QString&, const QString& ) ),
-	         this, SIGNAL( receivedAwayMessage( const QString&, const QString& ) ) );
-	connect( d->typingNotifyTask, SIGNAL( typingStarted( const QString& ) ),
-	         this, SIGNAL( userStartedTyping( const QString& ) ) );
-	connect( d->typingNotifyTask, SIGNAL( typingFinished( const QString& ) ),
-	         this, SIGNAL( userStoppedTyping( const QString& ) ) );
+	connect( d->userInfoTask, SIGNAL(receivedProfile(QString,QString)),
+	         this, SIGNAL(receivedProfile(QString,QString)) );
+	connect( d->userInfoTask, SIGNAL(receivedAwayMessage(QString,QString)),
+	         this, SIGNAL(receivedAwayMessage(QString,QString)) );
+	connect( d->typingNotifyTask, SIGNAL(typingStarted(QString)),
+	         this, SIGNAL(userStartedTyping(QString)) );
+	connect( d->typingNotifyTask, SIGNAL(typingFinished(QString)),
+	         this, SIGNAL(userStoppedTyping(QString)) );
 }
 
 void Client::removeGroup( const QString& groupName )
@@ -1104,8 +1105,8 @@ void Client::sendWarning( const QString& contact, bool anonymous )
 	WarningTask* warnTask = new WarningTask( c->rootTask() );
 	warnTask->setContact( contact );
 	warnTask->setAnonymous( anonymous );
-	QObject::connect( warnTask, SIGNAL( userWarned( const QString&, quint16, quint16 ) ),
-	                  this, SIGNAL( userWarned( const QString&, quint16, quint16 ) ) );
+	QObject::connect( warnTask, SIGNAL(userWarned(QString,quint16,quint16)),
+	                  this, SIGNAL(userWarned(QString,quint16,quint16)) );
 	warnTask->go( Task::AutoDelete );
 }
 
@@ -1361,9 +1362,9 @@ void Client::whitePagesSearch( const ICQWPSearchInfo& info )
 	if ( !c )
 		return;
 	UserSearchTask* ust = new UserSearchTask( c->rootTask() );
-	connect( ust, SIGNAL( foundUser( const ICQSearchResult& ) ),
-	         this, SIGNAL( gotSearchResults( const ICQSearchResult& ) ) );
-	connect( ust, SIGNAL( searchFinished( int ) ), this, SIGNAL( endOfSearch( int ) ) );
+	connect( ust, SIGNAL(foundUser(ICQSearchResult)),
+	         this, SIGNAL(gotSearchResults(ICQSearchResult)) );
+	connect( ust, SIGNAL(searchFinished(int)), this, SIGNAL(endOfSearch(int)) );
 	ust->go( Task::AutoDelete ); //onGo does nothing in this task. This is just here so autodelete works
 	ust->searchWhitePages( info );
 }
@@ -1374,9 +1375,9 @@ void Client::uinSearch( const QString& uin )
 	if ( !c )
 		return;
 	UserSearchTask* ust = new UserSearchTask( c->rootTask() );
-	connect( ust, SIGNAL( foundUser( const ICQSearchResult& ) ),
-	         this, SIGNAL( gotSearchResults( const ICQSearchResult& ) ) );
-	connect( ust, SIGNAL( searchFinished( int ) ), this, SIGNAL( endOfSearch( int ) ) );
+	connect( ust, SIGNAL(foundUser(ICQSearchResult)),
+	         this, SIGNAL(gotSearchResults(ICQSearchResult)) );
+	connect( ust, SIGNAL(searchFinished(int)), this, SIGNAL(endOfSearch(int)) );
 	ust->go( Task::AutoDelete ); //onGo does nothing in this task. This is just here so autodelete works
 	ust->searchUserByUIN( uin );
 }
@@ -1406,7 +1407,7 @@ bool Client::updateProfile( const QList<ICQInfoBase*>& infoList )
 void Client::sendTyping( const QString & contact, bool typing )
 {
 	Connection* c = d->connections.connectionForFamily( 0x0004 );
-	if ( !c )
+	if ( !c || !d->active )
 		return;
 	d->typingNotifyTask->setParams( contact, ( typing ? TypingNotifyTask::Begin : TypingNotifyTask::Finished ) );
 	d->typingNotifyTask->go(); 	// don't delete the task after sending
@@ -1419,7 +1420,6 @@ void Client::connectToIconServer()
 		return;
 
 	requestServerRedirect( 0x0010 );
-	return;
 }
 
 void Client::setIgnore( const QString& user, bool ignore )
@@ -1477,8 +1477,8 @@ void Client::requestBuddyIcon( const QString& user, const QByteArray& hash, Osca
 		return;
 
 	BuddyIconTask* bit = new BuddyIconTask( c->rootTask() );
-	connect( bit, SIGNAL( haveIcon( const QString&, QByteArray ) ),
-	         this, SIGNAL( haveIconForContact( const QString&, QByteArray ) ) );
+	connect( bit, SIGNAL(haveIcon(QString,QByteArray)),
+	         this, SIGNAL(haveIconForContact(QString,QByteArray)) );
 	bit->requestIconFor( user );
 	bit->setIconType( iconType );
 	bit->setHashType( hashType );
@@ -1517,8 +1517,8 @@ void Client::requestServerRedirect( Oscar::WORD family, Oscar::WORD exchange,
         srt->setChatRoom( room );
     }
 
-	connect( srt, SIGNAL( haveServer( const QString&, const QByteArray&, Oscar::WORD ) ),
-	         this, SLOT( haveServerForRedirect( const QString&, const QByteArray&, Oscar::WORD ) ) );
+	connect( srt, SIGNAL(haveServer(QString,QByteArray,Oscar::WORD)),
+	         this, SLOT(haveServerForRedirect(QString,QByteArray,Oscar::WORD)) );
 	srt->setService( family );
 	srt->go( Task::AutoDelete );
 }
@@ -1547,11 +1547,11 @@ void Client::haveServerForRedirect( const QString& host, const QByteArray& cooki
 	//create the new login task
 	d->loginTaskTwo = new StageTwoLoginTask( c->rootTask() );
 	d->loginTaskTwo->setCookie( cookie );
-	QObject::connect( d->loginTaskTwo, SIGNAL( finished() ), this, SLOT( serverRedirectFinished() ) );
+	QObject::connect( d->loginTaskTwo, SIGNAL(finished()), this, SLOT(serverRedirectFinished()) );
 
 	//connect
-	connectToServer( c, realHost, realPort.toInt(), false );
-  	QObject::connect( c, SIGNAL( connected() ), this, SLOT( streamConnected() ) );
+	connectToServer( c, realHost, realPort.toInt() );
+  	QObject::connect( c, SIGNAL(connected()), this, SLOT(streamConnected()) );
 
     if ( srt )
         d->connections.addChatInfoForConnection( c, srt->chatExchange(), srt->chatRoomName() );
@@ -1579,8 +1579,8 @@ void Client::serverRedirectFinished()
 
 	if ( d->currentRedirect == 0x000D )
 	{
-		connect( this, SIGNAL( chatNavigationConnected() ),
-				 this, SLOT( requestChatNavLimits() ) );
+		connect( this, SIGNAL(chatNavigationConnected()),
+				 this, SLOT(requestChatNavLimits()) );
 		emit chatNavigationConnected();
 	}
 
@@ -1601,12 +1601,12 @@ void Client::serverRedirectFinished()
 		{
 			kDebug(OSCAR_RAW_DEBUG) << "setting up chat connection";
 			ChatServiceTask* cst = new ChatServiceTask( c->rootTask(), exchange, roomName );
-			connect( cst, SIGNAL( userJoinedChat( Oscar::WORD, const QString&, const QString& ) ),
-			         this, SIGNAL( userJoinedChat( Oscar::WORD, const QString&, const QString& ) ) );
-			connect( cst, SIGNAL( userLeftChat( Oscar::WORD, const QString&, const QString& ) ),
-			         this, SIGNAL( userLeftChat( Oscar::WORD, const QString&, const QString& ) ) );
-			connect( cst, SIGNAL( newChatMessage( const Oscar::Message& ) ),
-			         this, SIGNAL( messageReceived( const Oscar::Message& ) ) );
+			connect( cst, SIGNAL(userJoinedChat(Oscar::WORD,QString,QString)),
+			         this, SIGNAL(userJoinedChat(Oscar::WORD,QString,QString)) );
+			connect( cst, SIGNAL(userLeftChat(Oscar::WORD,QString,QString)),
+			         this, SIGNAL(userLeftChat(Oscar::WORD,QString,QString)) );
+			connect( cst, SIGNAL(newChatMessage(Oscar::Message)),
+			         this, SIGNAL(messageReceived(Oscar::Message)) );
 		}
 		emit chatRoomConnected( exchange, roomName );
 	}
@@ -1637,8 +1637,8 @@ void Client::requestChatNavLimits()
 	kDebug(OSCAR_RAW_DEBUG) << "requesting chat nav service limits";
 	ChatNavServiceTask* cnst = new ChatNavServiceTask( c->rootTask() );
     cnst->setRequestType( ChatNavServiceTask::Limits );
-    QObject::connect( cnst, SIGNAL( haveChatExchanges( const QList<int>& ) ),
-                      this, SLOT( setChatExchangeList( const QList<int>& ) ) );
+    QObject::connect( cnst, SIGNAL(haveChatExchanges(QList<int>)),
+                      this, SLOT(setChatExchangeList(QList<int>)) );
 	cnst->go( Task::AutoDelete ); //autodelete
 
 }
@@ -1689,8 +1689,8 @@ void Client::joinChatRoom( const QString& roomName, int exchange )
     kDebug(OSCAR_RAW_DEBUG) << "joining the chat room '" << roomName
                              << "' on exchange " << exchange << endl;
     ChatNavServiceTask* cnst = new ChatNavServiceTask( c->rootTask() );
-    connect( cnst, SIGNAL( connectChat( Oscar::WORD, QByteArray, Oscar::WORD, const QString& ) ),
-             this, SLOT( setupChatConnection( Oscar::WORD, QByteArray, Oscar::WORD, const QString& ) ) );
+    connect( cnst, SIGNAL(connectChat(Oscar::WORD,QByteArray,Oscar::WORD,QString)),
+             this, SLOT(setupChatConnection(Oscar::WORD,QByteArray,Oscar::WORD,QString)) );
     cnst->createRoom( exchange, roomName );
 
 }
@@ -1713,9 +1713,26 @@ void Client::disconnectChatRoom( Oscar::WORD exchange, const QString& room )
     c = 0;
 }
 
+void Client::connectToServer( Connection* c, const QString& host, quint16 port )
+{
+	d->connections.append( c );
+	connect( c, SIGNAL(socketError(int,QString)), this, SLOT(determineDisconnection(int,QString)) );
+	c->connectToServer( host, port );
+}
+
+ClientStream* Client::createClientStream()
+{
+	ClientStream* cs = 0;
+	emit createClientStream( &cs );
+	if ( !cs )
+		cs = new ClientStream( new QTcpSocket(), 0 );
+
+	return cs;
+}
+
 Connection* Client::createConnection()
 {
-	ClientStream* cs = new ClientStream( new QTcpSocket(), 0 );
+	ClientStream* cs = createClientStream();
 	cs->setNoopTime( 60000 );
 	Connection* c = new Connection( cs, "BOS" );
 	cs->setConnection( c );
@@ -1763,12 +1780,20 @@ FileTransferHandler* Client::createFileTransfer( const QString& contact, const Q
 		return 0;
 
 	FileTransferTask *ft = new FileTransferTask( c->rootTask(), contact, ourInfo().userId(), files );
-	connect( ft, SIGNAL( sendMessage( const Oscar::Message& ) ),
-	         this, SLOT( fileMessage( const Oscar::Message& ) ) );
+	connect( ft, SIGNAL(sendMessage(Oscar::Message)),
+	         this, SLOT(fileMessage(Oscar::Message)) );
 
 	return new FileTransferHandler(ft);
 }
 
+void Client::inviteToChatRoom( const QString& contact, Oscar::WORD exchange, const QString& room, QString msg)
+{
+	Connection* c = d->connections.connectionForFamily( 0x0004 );
+	ChatRoomTask *chatRoomTask = new ChatRoomTask( c->rootTask(), contact, ourInfo().userId(), msg, exchange, room);
+	chatRoomTask->go( Task::AutoDelete );
+	chatRoomTask->doInvite();
+}
+
 void Client::gotChatRoomMessage( const Oscar::Message & msg, const QByteArray & cookie )
 {
 	Connection* c = d->connections.connectionForFamily( 0x0004 );
@@ -1799,8 +1824,8 @@ void Client::gotFileMessage( int type, const QString from, const QByteArray cook
 	{
 		kDebug(14151) << "new request :)";
 		FileTransferTask *ft = new FileTransferTask( c->rootTask(), from, ourInfo().userId(), cookie, buf );
-		connect( ft, SIGNAL( sendMessage( const Oscar::Message& ) ),
-				this, SLOT( fileMessage( const Oscar::Message& ) ) );
+		connect( ft, SIGNAL(sendMessage(Oscar::Message)),
+				this, SLOT(fileMessage(Oscar::Message)) );
 		ft->go( Task::AutoDelete );
 		
 		emit incomingFileTransfer( new FileTransferHandler(ft) );
@@ -1809,5 +1834,7 @@ void Client::gotFileMessage( int type, const QString from, const QByteArray cook
 	kDebug(14151) << "nobody wants it :(";
 }
 
+}
+
 #include "client.moc"
 //kate: tab-width 4; indent-mode csands; space-indent off; replace-tabs off;
